from wagtail.core.blocks import (
    CharBlock,
    RichTextBlock,
    StreamBlock,
    StructBlock,
)
from wagtail.images.blocks import ImageChooserBlock

from ..media.blocks import MediaBlock


class ImageBlock(StructBlock):
    """
    Bloc contenant une image, avec une légende et une attribution
    optionnelles associées.
    """

    image = ImageChooserBlock(label="Image", required=True)
    caption = RichTextBlock(
        label="Légende",
        required=False,
        features=['bold', 'italic', 'link', 'document-link'],
    )
    attribution = CharBlock(label="Attribution", required=False)

    class Meta:
        label = "Image"
        icon = 'image'
        template = 'blocks/image.html'


class FAQBlock(StructBlock):
    """
    Bloc contenant une question et sa réponse associée.
    """

    question = CharBlock(label="Question", required=True)
    answer = RichTextBlock(
        label="Réponse",
        required=True,
        features=['bold', 'italic', 'ol', 'ul', 'link', 'document-link'],
    )

    class Meta:
        label = "Question - réponse"
        icon = 'help'
        template = 'blocks/faq.html'


class BaseStreamBlock(StreamBlock):
    """
    Blocs de base utilisés dans un champ ``StreamField``.
    """

    paragraph_block = RichTextBlock(label="Paragraphe", icon='pilcrow')
    image_block = ImageBlock()
    media_block = MediaBlock()
