from django.contrib import admin
from django.urls import reverse
from django.utils.html import format_html

from .models import Appel, Participant, Question


def participant_link(obj):
    return format_html(
        '<a href="{}">{}{}</a>',
        reverse(
            'admin:forum_participant_change', args=(obj.participant_ptr.id,)
        ),
        obj.id,
        ' ({})'.format(obj.session_id[:10]) if obj.session_id else '',
    )


participant_link.short_description = "Participant"  # noqa


class ParticipantAdmin(admin.ModelAdmin):
    list_display = ('id', 'genre', 'age', 'ville')
    readonly_fields = ('session_id',)


class QuestionAdmin(admin.ModelAdmin):
    list_display = (
        'id',
        'status',
        'question',
        'answer',
        'email',
        participant_link,
        'created_at',
        'last_modified_at',
    )

    list_editable = ('status',)
    list_filter = ('status', 'age')


class AppelAdmin(admin.ModelAdmin):
    list_display = (
        'id',
        'status',
        'objet',
        'telephone',
        'compteur',
        participant_link,
        'created_at',
        'last_modified_at',
    )
    list_editable = ('status',)
    list_filter = ('status', 'age')
    readonly_fields = ('compteur',)


admin.site.register(Participant, ParticipantAdmin)
admin.site.register(Question, QuestionAdmin)
admin.site.register(Appel, AppelAdmin)
