import logging

from django.template.loader import render_to_string
from django.utils.safestring import mark_safe

from wagtail.core.blocks import RichTextBlock, StructBlock
from wagtailmedia.blocks import AbstractMediaChooserBlock

logger = logging.getLogger(__name__)


class MediaChooserBlock(AbstractMediaChooserBlock):
    def render_basic(self, value, context=None):
        if not value or not value.type:
            logger.error("Impossible de produire le rendu de %r", value)
            return ''

        template = 'blocks/media_{}.html'.format(value.type)

        if context is None:
            context = self.get_context(value)
        else:
            context = self.get_context(value, parent_context=dict(context))

        return mark_safe(render_to_string(template, context))


class MediaBlock(StructBlock):
    """
    Bloc contenant un média, avec une légende optionnelle associée.
    """

    media = MediaChooserBlock(label="Média", required=True)
    caption = RichTextBlock(
        label="Légende",
        required=False,
        features=['bold', 'italic', 'link', 'document-link'],
    )

    class Meta:
        label = "Média"
        icon = 'media'
        template = 'blocks/media.html'
