import mimetypes
import os.path
from argparse import FileType

from django.core.management.base import BaseCommand, CommandError

from jcpml.media.models import SourceMedia

MEDIA_TYPES = set(t[0] for t in SourceMedia.MEDIA_TYPES)


class Command(BaseCommand):
    help = "Ajoute un nouveau média"

    def add_arguments(self, parser):
        # arguments requis
        parser.add_argument(
            'source',
            type=FileType('rb'),
            metavar='FILE',
            help="Fichier source du média",
        )
        parser.add_argument(
            '--title', '-t', required=True, help="Titre du média"
        )
        # arguments optionnels
        parser.add_argument(
            '--thumbnail',
            '-i',
            default=None,
            type=FileType('rb'),
            help="Minitature à utiliser pour le média",
        )

    def handle(self, **options):
        source = options['source']
        thumbnail = options['thumbnail']

        # devine et valide le type de média
        mime_type = mimetypes.guess_type(source.name)[0]
        if not mime_type:
            raise CommandError(
                "Impossible de deviner le type de média depuis le fichier"
            )
        media_type = mime_type.split('/')[0]
        if media_type not in MEDIA_TYPES:
            raise CommandError(
                "Le type de fichier '{}' n'est pas supporté comme média "
                "({})".format(media_type, ', '.join(MEDIA_TYPES))
            )

        # crée et enregistre le nouveau média
        media = SourceMedia(
            title=options['title'], type=media_type, mime_type=mime_type
        )
        media.file.save(os.path.basename(source.name), source, save=False)
        if thumbnail:
            media.thumbnail.save(
                os.path.basename(thumbnail.name), thumbnail, save=False
            )
        media.save()

        self.stderr.write(
            self.style.SUCCESS(
                "Le média « {} » ({}) a été ajouté".format(
                    media.title, media.id
                )
            )
        )
