import json
import locale
import logging
import subprocess
from functools import lru_cache
from shutil import which

from django.conf import settings

logger = logging.getLogger(__name__)

CONSOLE_ENCODING = locale.getdefaultlocale()[1] or 'UTF-8'


@lru_cache()
def get_ffprobe_path():
    """
    Retourne le chemin vers 'ffprobe', s'il est présent.
    """
    ffprobe_path = getattr(settings, 'FFPROBE_PATH', which('ffprobe'))
    if not ffprobe_path:
        logger.error("Impossible de trouver le chemin vers 'ffprobe'")
    return ffprobe_path


def get_media_info(media_path):
    """
    Récupère les informations d'un média avec ffprobe.
    """
    ffprobe_path = get_ffprobe_path()
    if not ffprobe_path:
        return {}
    output = subprocess.check_output(
        [
            ffprobe_path,
            '-v',
            'quiet',
            '-print_format',
            'json',
            '-show_format',
            '-show_streams',
            media_path,
        ]
    )
    # décode et regroupe les informations par flux
    media_info = json.loads(output.decode(CONSOLE_ENCODING))
    if media_info and 'streams' in media_info:
        streams = {'audio': [], 'video': [], 'subtitle': [], 'other': []}
        for stream in media_info['streams']:
            try:
                streams[stream['codec_type']].append(stream)
            except KeyError:
                streams['other'].append(stream)
        media_info['streams'] = streams
    return media_info
