from django.test.html import parse_html
from django.utils.html import conditional_escape


def parse_content(response, html=False):
    """
    Décode et retourne le contenu de la réponse, en le transformant en
    objet de structure Python si `html` vaut `True`.
    """
    if (
        hasattr(response, "render")
        and callable(response.render)
        and not response.is_rendered
    ):
        response.render()
    content = response.content.decode(response.charset)
    return parse_html(content) if html else content


def count_text_in_content(response, text, html=False, escape=True):
    """
    Retourne le nombre d'occurrence de `text` dans le contenu de la réponse,
    en l'interprétant en tant que HTML si `html` vaut `True`. Sinon, les
    caractères sensibles seront échapés en HTML si `escape` vaut `True`.

    Cette méthode se base sur `django.test.SimpleTestCase.assertContains()`,
    et pourrait être remplacée après l'intégration de pytest-django#709.
    """
    content = parse_content(response, html=html)
    if not html:
        text = conditional_escape(text) if escape else str(text)
    else:
        text = parse_html(text)
    return content.count(text)
