import datetime

from django import forms

import pytest

from ..forms import CustomTapeformMixin


class DummyForm(CustomTapeformMixin, forms.Form):
    CHOICES = (('foo', 'foo'), ('bar', 'bar'))

    default = forms.CharField()
    checkbox = forms.BooleanField()
    select = forms.ChoiceField(choices=CHOICES)
    date = forms.DateField()


@pytest.fixture
def form():
    return DummyForm()


class TestCustomTapeformMixin:
    def test_base_layout_template(self, form):
        assert form.base_layout_template == 'tapeforms/layouts/bootstrap.html'

    def test_date_input_format(self, form):
        widget = form.fields['date'].widget
        assert widget.format == '%Y-%m-%d'
        assert widget.format_value(datetime.date(2019, 1, 1)) == '2019-01-01'

    def test_css_class_default(self, form):
        assert (
            form.get_field_container_css_class(form['default']) == 'form-group'
        )
        assert form.get_field_label_css_class(form['default']) is None
        assert (
            form.get_widget_css_class('default', form.fields['default'])
            == 'form-control'
        )

    def test_css_class_checkbox(self, form):
        assert (
            form.get_field_container_css_class(form['checkbox'])
            == 'form-group custom-control custom-checkbox'
        )
        assert (
            form.get_field_label_css_class(form['checkbox'])
            == 'custom-control-label'
        )
        assert (
            form.get_widget_css_class('checkbox', form.fields['checkbox'])
            == 'custom-control-input'
        )

    def test_css_class_select(self, form):
        assert (
            form.get_widget_css_class('select', form.fields['select'])
            == 'custom-select'
        )
